# Data  from Nature Paper    
Submitted Jan 26, 2014    
[**Computational analysis of cell-to-cell heterogeneity in single-cell RNA-sequencing data reveals hidden subpopulations of cells**](http://www.nature.com/nbt/journal/v33/n2/full/nbt.3102.html)

# Tables of interest    
  * [401 genes differentially expressed](./nbt.3102-S4.xlsx)    
  * [Gene Ontology Enrichment Analysis (GOEA)](./nbt.3102-S6.xlsx)    

Copyright (C) 2010-2018, H Tang et al. All rights reserved.
